Gemeinde Adressverwaltung GUI: Gemeinde.Main Klassenreferenz

Gemeinde Adressverwaltung GUI

Öffentliche Methoden | Öffentliche Attribute | Aufstellung aller Elemente
Gemeinde.Main Klassenreferenz
Klassendiagramm für Gemeinde.Main:
[Legende]
Zusammengehörigkeiten von Gemeinde.Main:
[Legende]

## Öffentliche Methoden
def | __init__ (self)
def | basics (self)
def | handleQuit (self, event)
def | ende (self)
def | loginAndSelectGemeinde (self)
def | baueMenuBar (self)
def | handleMnuLogin (self, event=None)
def | handleMnuLogout (self, tolerant=False)
def | baueValidatoren (self)
def | baueWidgets (self)
def | baueLayout (self)

## Öffentliche Attribute
| style
| mnuBar
| mnuDatei
| mnuDB
| mnuHilfe
| valDate
| invalidHoldFocus
| varGlbDB
| varGlbUser
| varGlbGemeinde
| lblGlbDB
| entGlbDB
| lblGlbUser
| entGlbUser
| lblGlbGemeinde
| entGlbGemeinde
| wdgNotify
| frmPersEinzelNavi
| frmPersEinzelDaten
| frmPersEinzelUnterformulare
| sfrPersEinzelGruppen
| sfrPersEinzelVersand
| frmPersEinzelGruppen
| frmPersEinzelVersand
| frmFamEinzelNavi
| frmFamEinzelDaten
| frmFamEinzelUnterformulare
| sfrFamEinzelGruppen
| sfrFamEinzelVersand
| frmFamEinzelGruppen
| frmFamEinzelVersand
| frmGruppenNavi
| frmGruppenDaten
| frmVersandartenNavi
| frmVersandartenDaten
| frmAnredenNavi
| frmAnredenDaten
| frmFarbenNavi
| frmFarbenDaten
| frmGemeindenNavi
| frmGemeindenDaten
| mailAttachments
| mailVerteiler
| frmMail
| frmMailSteuerung
| frmMailGruppen
| frmMailVersandarten
| frmMailKontrolle
| frmMailButtons
| frmMailAnhangButtons
| btnAnhang
| btnAnhangClear
| btnCheck
| btnSend
| btnReset
| frmTop
| pndHauptUndFuss
| frmMain
| frmBottom
| nbkMain
| frmNbkPersonen
| nbkPersonen
| frmNbkFamilien
| nbkFamilien
| frmNbkHelferlein
| nbkHelferlein
| frmNbkAktionen
| nbkAktionen
| frmNbkVerwaltung
| nbkVerwaltung
| frmPersonenEinzelheiten
| frmPersonenListe
| frmFamilienEinzelheiten
| frmFamilienListe
| frmGruppenEinzelheiten
| frmVersandartenEinzelheiten
| frmAnredenEinzelheiten
| frmMailVersand
| frmFarbenEinzelheiten
| frmGemeindenEinzelheiten

## Dokumentation der Elementfunktionen

## ◆ handleMnuLogin()

def Gemeinde.Main.handleMnuLogin | ( |  | self,
|  |  | event = `None`
| ) |  |

    handleMnuLogin - Behandelt Menü Login Button

## ◆ handleMnuLogout()

def Gemeinde.Main.handleMnuLogout | ( |  | self,
|  |  | tolerant = `False`
| ) |  |

    handleMnuLogout - Behandelt Menü Logout Button

## ◆ handleQuit()

def Gemeinde.Main.handleQuit | ( |  | self,
|  |  | event
| ) |  |

    handleQuit - Beendet das Programm nach HotKey

        Ruft einfach nur ende auf.

## ◆ loginAndSelectGemeinde()

def Gemeinde.Main.loginAndSelectGemeinde | ( |  | self | ) |

    loginAndSelectGemeinde - Login und Auswahl der Gemeinde

        Ruft Login Dialog so oft auf, bis gültige Login Daten eingegeben wurden.
        Falls über die Kommandozeile bereits Login Daten vorhanden sind,
        werden die als erstes versucht; im Erfolgsfall wird der Login Dialog
        nicht aufgerufen.

        Beachte die Seiteneffekte von checkLogin auf glb.DB und
        glb.Gemeinden!

        Anschließend wird ein Select Dialog mit den verfügbaren Gemeinden
        aufgerufen; der Benutzer muss dort die Gemeinde auswählen, die
        er bearbeiten möchte.
        Die Auswahl wird dadurch wirksam, dass dann der PostgreSQL
        search_path entsprechend gesetzt wird.

Die Dokumentation für diese Klasse wurde erzeugt aufgrund der Datei:

- Gemeinde.py